summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPanu Matilainen <pmatilai@redhat.com>2017-12-13 12:06:45 +0200
committerPanu Matilainen <pmatilai@redhat.com>2018-03-28 13:28:09 +0300
commite414dc2af8d29ec0b38fe8d53cc27e102dc83f9d (patch)
treedd07b6e5e0ff731abd5333cc8b71550cf8b3430f
parent5094ce9812494b577e28b301f4441a37368792af (diff)
downloadrpm-e414dc2af8d29ec0b38fe8d53cc27e102dc83f9d.tar.gz
Fixups to file trigger internal api docs + comments
(cherry picked from commit 5dc33a852d83a63e55fbd000c60a29a7d2822ed7)
-rw-r--r--lib/rpmtriggers.c2
-rw-r--r--lib/rpmtriggers.h12
2 files changed, 7 insertions, 7 deletions
diff --git a/lib/rpmtriggers.c b/lib/rpmtriggers.c
index 769c6f25b..743ba8dee 100644
--- a/lib/rpmtriggers.c
+++ b/lib/rpmtriggers.c
@@ -452,7 +452,7 @@ static int matchFilesInPkg(rpmts ts, rpmte te, const char *pfx,
return rc;
}
-/* Return true if any added/removed file in ts starts with pfx */
+/* Return number of added/removed files starting with pfx in transaction */
static int matchFilesInTran(rpmts ts, rpmte te, const char *pfx,
rpmsenseFlags sense)
{
diff --git a/lib/rpmtriggers.h b/lib/rpmtriggers.h
index bca79b8fe..2f8f369be 100644
--- a/lib/rpmtriggers.h
+++ b/lib/rpmtriggers.h
@@ -51,31 +51,31 @@ int runPostUnTransFileTrigs(rpmts ts);
* @param te transaction entry
* @param sense defines which triggers should be set off (triggerin,
* triggerun, triggerpostun)
* @param triggerClass 1 to run triggers that should be executed before
* standard scriptlets
* 2 to run triggers that should be executed after
* standard scriptlets
* 0 to run all triggers
- * @param tm trigger mode, (filetrigger/transfiletrigger)
*/
RPM_GNUC_INTERNAL
rpmRC runFileTriggers(rpmts ts, rpmte te, rpmsenseFlags sense,
- rpmscriptTriggerModes tm, int upper);
+ rpmscriptTriggerModes tm, int priorityClass);
/* Run file triggers in this te other package(s) set off.
* @param ts transaction set
* @param te transaction entry
* @param sense defines which triggers should be set off (triggerin,
* triggerun, triggerpostun)
* @param triggerClass 1 to run triggers that should be executed before
* standard scriptlets
* 2 to run triggers that should be executed after
* standard scriptlets
* 0 to run all triggers
- * @param tm trigger mode, (filetrigger/transfiletrigger)
*/
rpmRC runImmedFileTriggers(rpmts ts, rpmte te, rpmsenseFlags sense,
- rpmscriptTriggerModes tm, int upper);
+ rpmscriptTriggerModes tm, int priorityClass);
#ifdef __cplusplus
}
#endif
@@ -51,31 +51,31 @@ int runPostUnTransFileTrigs(rpmts ts);
* @param sense defines which triggers should be set off (triggerin,
* triggerun, triggerpostun)
- * @param triggerClass 1 to run triggers that should be executed before
+ * @param tm trigger mode, (filetrigger/transfiletrigger)
+ * @param priorityClass 1 to run triggers that should be executed before
* standard scriptlets
* 2 to run triggers that should be executed after
@@ -51,31 +51,31 @@ int runPostUnTransFileTrigs(rpmts ts);
* @param sense defines which triggers should be set off (triggerin,
* triggerun, triggerpostun)
- * @param triggerClass 1 to run triggers that should be executed before
+ * @param tm trigger mode, (filetrigger/transfiletrigger)
+ * @param priorityClass 1 to run triggers that should be executed before
* standard scriptlets
* 2 to run triggers that should be executed after